| Title: | An Improved Multiple Testing Procedure for Controlling False Discovery Rates |
|---|---|
| Description: | An improved multiple testing procedure for controlling false discovery rates which is developed based on the Bonferroni procedure with integrated estimates from the Benjamini-Hochberg procedure and the Storey's q-value procedure. It controls false discovery rates through controlling the expected number of false discoveries. |
| Authors: | Dongmei Li |
| Maintainer: | Dongmei Li <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.0 |
| Built: | 2026-05-26 06:21:17 UTC |
| Source: | https://github.com/cran/BonEV |
BonEV is an improved multiple testing procedure for controlling false discovery rates which is developed based on the Bonferroni procedure with integrated estimates from the Benjamini-Hochberg procedure and the Storey's q-value procedure. It controls false discovery rates through controlling the expected number of false discoveries.
| Package: | BonEV |
| Type: | Package |
| Version: | 1.0.0 |
| Date: | 2015-02-10 |
| Depends: | R (>= 3.2.0), qvalue |
| License: | GPL (>= 2) |
Dongmei Li Maintainer: Dongmei Li <[email protected]>
The Bon_EV function defined in this package.
The qvalue package.
library(qvalue) data(hedenfalk) summary(hedenfalk) pvalues <- hedenfalk$p adjp <- Bon_EV(pvalues, 0.05) summary(adjp) results <- cbind(adjp$raw_P_value, adjp$BH_adjp, adjp$Storey_adjp, adjp$Bon_EV_adjp) results ##Compare with Benjamini-Hochberg and Storey's q-value procedures sum(adjp$raw_P_value <= 0.05) sum(adjp$BH_adjp <= 0.05) sum(adjp$Storey_adjp <= 0.05) sum(adjp$Bon_EV_adjp <= 0.05)library(qvalue) data(hedenfalk) summary(hedenfalk) pvalues <- hedenfalk$p adjp <- Bon_EV(pvalues, 0.05) summary(adjp) results <- cbind(adjp$raw_P_value, adjp$BH_adjp, adjp$Storey_adjp, adjp$Bon_EV_adjp) results ##Compare with Benjamini-Hochberg and Storey's q-value procedures sum(adjp$raw_P_value <= 0.05) sum(adjp$BH_adjp <= 0.05) sum(adjp$Storey_adjp <= 0.05) sum(adjp$Bon_EV_adjp <= 0.05)
Bon_EV is an improved multiple testing procedure for controlling false discovery rates which is developed based on the Bonferroni procedure with integrated estimates from the Benjamini-Hochberg procedure and the Storey's q-value procedure. It controls false discovery rates through controlling the expected number of false discoveries.
Bon_EV(pvalue, alpha)Bon_EV(pvalue, alpha)
pvalue |
The input data is a vector of P-values ranged from 0 to 1 |
alpha |
The alpha is the level of false discovery rates (FDR) to control for |
Bon_EV is a function for getting adjusted P-values with FDR controlled at level alpha.
Bon_EV produces a named list with the following components:
raw_P_value |
Vector of raw P-values |
BH_adjp |
Adjusted P-values from the Benjamini-Hochberg procedure |
Storey_adjp |
Adjusted P-values from the Storey's q-value procedure |
Bon_EV_adjp |
Adjusted P-values from the Bon-EV multiple testing procedure |
Dongmei Li
The qvalue package.
library(qvalue) data(hedenfalk) summary(hedenfalk) pvalues <- hedenfalk$p adjp <- Bon_EV(pvalues, 0.05) summary(adjp) sum(adjp$Bon_EV_adjp <= 0.05)library(qvalue) data(hedenfalk) summary(hedenfalk) pvalues <- hedenfalk$p adjp <- Bon_EV(pvalues, 0.05) summary(adjp) sum(adjp$Bon_EV_adjp <= 0.05)